@@ -126,18 +126,8 @@
 #'@return Prints ANOVA statistics (including, for each model, F-test with
 #'  partial eta squared and its CI, generalized eta squared, and BF, as
 #'  specified via the corresponding parameters) in APA style. Furthermore, when
-#'  assigned, returns a list with up to four elements. First,
-#'  '\code{stat_list}', a list of named vectors per each effect (main or
-#'  interaction). Each vector contains the following elements: \code{F} (F
-#'  value), \code{p} (p value), \code{petas} (partial eta squared), \code{getas}
-#'  (generalized eta squared), \code{epsilon} (epsilon used for correction), and
-#'  \code{bf} (inclusion BF; when \code{bf_added} is not \code{FALSE}). Second,
-#'  a dataframe with mean and SD per each condition (i.e., per each level per
-#'  each factor). Third, the \code{\link[ez]{ezANOVA}} object, named
-#'  \code{ez_anova} (calculated even when \code{\link[stats]{oneway.test}} is
-#'  printed). Fourth, when \code{bf_added} is not \code{FALSE}, the
-#'  \code{\link[BayesFactor]{anovaBF}} object, named \code{bf_models}; including
-#'  all models on which the inclusion BFs are based.
+#'  assigned, returns all calculated information details for each effect (as
+#'  \code{stat_list}), normality and variance tests (if any), etc.
 #'
 #'@note The F-tests are calculated via \code{\link[ez:ezANOVA]{ez::ezANOVA}},
 #'  including Mauchly's sphericity test. (But Welch's ANOVA is
@@ -484,7 +474,7 @@ anova_neat = function(data_per_subject,
                 '" were collapsed (averaged) into one column.'
             )
             data_per_subject[[dup]] = rowMeans(data_per_subject[, to_collapse], na.rm =
-                                                      TRUE)
+                                                   TRUE)
             values = values[!(values %in% to_collapse)]
             values = c(values, dup)
         }
@@ -513,7 +503,7 @@ anova_neat = function(data_per_subject,
         eb_method = stats::sd,
         numerics = TRUE
     )
-    if (is.null(e_correction)){
+    if (is.null(e_correction)) {
         e_correction = ''
     }
     data_wide = data_per_subject
@@ -639,7 +629,8 @@ anova_neat = function(data_per_subject,
                     ', whichModels = "withmain")'
                 )
         ))
-        if (is.null(within_vars) && length(to_c(between_vars)) == 1) {
+        if (is.null(within_vars) &&
+            length(to_c(between_vars)) == 1) {
             bf_inc = as.vector(bf)
         } else {
             bf_inc = bayestestR::bayesfactor_inclusion(bf, match_models = TRUE)
@@ -684,17 +675,28 @@ anova_neat = function(data_per_subject,
             anov = TRUE
         )
     }
-    if (var_tests == TRUE && !is.null(bv_copy) &
-        hush == FALSE
-    ) {
-        prnt('--- Equality of Variances ---')
+    norm_info = all_norm_tests(resids)
+    var_info = NULL
+    if (!is.null(bv_copy)) {
+        if (var_tests == TRUE && hush == FALSE) {
+            var_hush = FALSE
+            prnt('--- Equality of Variances ---')
+        } else {
+            var_hush = TRUE
+        }
         if (is.null(within_vars)) {
-            neatStats::var_tests(value_col, bv_copy, this_data)
+            var_info = neatStats::var_tests(value_col, bv_copy, this_data, hush = var_hush)
         } else {
             for (fact in unique(this_data[[withname]])) {
-                cat(fact, ': ', sep = '', fill = TRUE)
-                neatStats::var_tests(value_col, bv_copy,
-                          this_data[this_data[[withname]] == fact, ])
+                if (isFALSE(var_hush)) {
+                    cat(fact,
+                        ': ',
+                        sep = '',
+                        fill = TRUE)
+                }
+                var_info[[fact]] = neatStats::var_tests(value_col, bv_copy,
+                                                        this_data[this_data[[withname]] == fact,],
+                                                        hush = var_hush)
             }
         }
     }
@@ -711,6 +713,9 @@ anova_neat = function(data_per_subject,
         resids = resids,
         fitt = fitt
     )
+    to_return$normality_tests = norm_info
+    to_return$variance_tests = var_info
+    class(to_return) = "anova_neat"
     invisible(to_return)
 }
 
@@ -735,13 +740,25 @@ anova_apa = function(ezANOVA_out,
         if (hush == FALSE) {
             prnt("--- Mauchly's Sphericity Test ---")
         }
-        eps_p_corrs = get_e_corrs(mauchly,
-                                  ezANOVA_out$"Sphericity Corrections",
-                                  e_correction, hush)
+        mauchly_info = get_e_corrs(mauchly,
+                                   ezANOVA_out$"Sphericity Corrections",
+                                   e_correction,
+                                   hush)
+        eps_p_corrs = mauchly_info$eps_p_corrs
+        mauchly_info$eps_p_corrs = NULL
+        mauchly_info = tryCatch({
+            as.data.frame(do.call(cbind, mauchly_info))
+        }, error = function(e) {
+            warning(
+                "Mauchly effects' lists not identical, returning as lists instead of a data frame."
+            )
+            mauchly_info
+        })
         if (hush == FALSE) {
             prnt("--- ANOVA ---")
         }
     } else {
+        mauchly_info = NULL
         eps_p_corrs = NULL
     }
     stat_list = list()
@@ -760,6 +777,7 @@ anova_apa = function(ezANOVA_out,
         F_val = ezANOVA_out$ANOVA$F[indx]
         df_n = ezANOVA_out$ANOVA$DFn[indx]
         df_d = ezANOVA_out$ANOVA$DFd[indx]
+        df_d_val = df_d
         pvalue = ezANOVA_out$ANOVA$p[indx]
         limits = MBESS::conf.limits.ncf(
             F.value = F_val,
@@ -772,25 +790,37 @@ anova_apa = function(ezANOVA_out,
         if (!is.null(welch)) {
             F_val = as.numeric(welch$statistic)
             df_n = as.numeric(welch$parameter['num df'])
+            df_d_val = as.numeric(welch$parameter['denom df'])
             df_d = ro(as.numeric(welch$parameter['denom df']), 1)
             pvalue = as.numeric(welch$p.value)
         }
         if (!is.null(eps_p_corrs[[f_name]])) {
             pvalue = as.numeric(eps_p_corrs[[f_name]]['pval'])
-            eps_num = ro(as.numeric(eps_p_corrs[[f_name]]['eps']), 3)
-            eps_added = paste0(', CHAR_EPS = ', eps_num)
+            eps_num = as.numeric(eps_p_corrs[[f_name]]['eps'])
+            eps_val = eps_num
+            eps_added = paste0(', CHAR_EPS = ', ro(eps_num, 3))
         } else {
+            if (is.null(mauchly_info)) {
+                eps_val = NULL
+            } else {
+                eps_val = NA
+            }
+            eps_num = NULL
             eps_added = NULL
         }
         petas = ezANOVA_out$ANOVA$pes[indx]
         if (is.na(lower)) {
+            lower_val = 0
             lower = "0"
         } else {
+            lower_val = lower
             lower = sub('.', '', ro(lower, 3))
         }
         if (is.na(upper)) {
+            upper_val = "< .001"
             upper = "< .001"
         } else {
+            upper_val = upper
             upper = sub('.', '', ro(upper, 3))
         }
         np2 = sub('.', '', ro(petas, 3))
@@ -807,7 +837,7 @@ anova_apa = function(ezANOVA_out,
             ro(F_val, 2),
             ", p = ",
             ro(pvalue, 3),
-            epsilon = eps_added,
+            eps_added,
             ", CHAR_ETAp2 = ",
             np2,
             the_ci,
@@ -824,22 +854,63 @@ anova_apa = function(ezANOVA_out,
         if (hush == FALSE) {
             prnt(out)
         }
-        s_name = gsub(" CHAR_X ", "_", f_name)
+        s_name = gsub(" CHAR_X ", "_x_", f_name)
         stat_list[[s_name]] = c(
-            F = as.numeric(F_val),
-            p = pvalue,
-            epsilon = eps_added,
+            Fval = as.numeric(F_val),
+            df1 = df_n,
+            df2 = df_d_val,
+            pval = pvalue,
+            epsilon = eps_val,
             petas = as.numeric(petas),
+            ci_lower = lower_val,
+            ci_upper = upper_val,
             getas = as.numeric(getas),
             bf = as.numeric(bf_val)
         )
     }
-    stat_list = list(effects = stat_list,
-                  ez_anova = ezANOVA_out,
-                  bf_models = bf_models,
-                  totals = dat_tot,
-                  residuals = resids,
-                  fitted = fitt)
-    class(stat_list) = c("neats_aov", class(stat_list))
+    stat_list = list(
+        effects =
+            tryCatch({
+                as.data.frame(do.call(rbind, stat_list))
+            }, error = function(e) {
+                warning("Effects' vectors not identical, returning as list instead of a data frame.")
+                stat_list
+            }),
+        mauchly = mauchly_info,
+        ci_level = ci,
+        ez_anova = ezANOVA_out,
+        bf_models = bf_models,
+        totals = dat_tot,
+        residuals = resids,
+        fitted = fitt
+    )
     invisible(stat_list)
 }
+
+all_norm_tests = function(var_to_norm) {
+    norm_tests = list()
+    norm_tests[['W']] = fBasics::shapiroTest(var_to_norm)@test
+    if (length(var_to_norm) >= 8) {
+        if (length(var_to_norm) >= 21) {
+            norm_tests[['K2']] = fBasics::dagoTest(var_to_norm)@test
+        }
+        norm_tests[['A2']] = fBasics::adTest(var_to_norm)@test
+    }
+    norm_tests[['JB']] = fBasics::jarqueberaTest(var_to_norm)@test
+    norms_out = list()
+    for (norm_stat in names(norm_tests)) {
+        norms_out[[norm_stat]] = list(
+            title = as.character(
+                c(
+                    'W' = 'Shapiro-Wilk test',
+                    'K2' = "D'Agostino test",
+                    'A2' = "Anderson-Darling test",
+                    'JB' = "Jarque-Bera test"
+                )[norm_stat]
+            ),
+            statistic = norm_tests[[norm_stat]]$statistic[[1]],
+            pval = norm_tests[[norm_stat]]$p.value[[1]]
+        )
+    }
+    return(as.data.frame(do.call(cbind, norms_out)))
+}
