@@ -485,7 +485,7 @@ t_neat = function(var1,
                         paired = pair,
                         iterations = bf_sample,
                         rscale = bf_rscale,
-                        nullInterval = c(0,-Inf)
+                        nullInterval = c(0, -Inf)
                     )[1]
                 )
             }
@@ -656,19 +656,19 @@ t_neat = function(var1,
             direction =  auc_dir
         ) # v1 larger
         youdn = pROC::coords(the_roc, x = "best", ret = "youden")
-        if (class(youdn) == "data.frame") {
+        if (inherits(youdn, "data.frame")) {
             maxyouden = as.numeric(youdn$youden[1]) - 1
         } else {
             maxyouden = as.numeric(youdn[1]) - 1
         }
         bestacc = pROC::coords(the_roc, x = "best", ret = "accuracy")
-        if (class(bestacc) == "data.frame") {
+        if (inherits(bestacc, "data.frame")) {
             max_acc = as.numeric(bestacc$accuracy[1])
         } else {
             max_acc = as.numeric(bestacc[1])
         }
         best_coords = pROC::coords(the_roc, x = "best")
-        if (class(best_coords) == "data.frame") {
+        if (inherits(best_coords, "data.frame")) {
             plot_thres = as.numeric(best_coords$threshold)[1]
             best_tp = as.numeric(best_coords$sensitivity)[1]
             best_tn = as.numeric(best_coords$specificity)[1]
@@ -868,7 +868,7 @@ plot_dens = function(v1,
                 guide = FALSE
             ) +
             geom_vline(
-                xintercept = c(xfunc(.data$v1), xfunc(.data$v2)),
+                xintercept = c(xfunc(dens_dat$v1), xfunc(dens_dat$v2)),
                 color = "#777777",
                 linetype = "dashed",
                 size = 0.5
